<!--
SPDX-FileCopyrightText: 2025 Contributors to the OpenSTEF project <openstef@lfenergy.org>

SPDX-License-Identifier: MPL-2.0
-->

# OpenSTEF Examples

Before you start, make sure to install all the necessary dependencies by running:

```bash
uv sync --all-extras --all-groups --all-packages
```